chrpa.main package
==================

Submodules
----------

chrpa.main.processing module
----------------------------

.. automodule:: chrpa.main.processing
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chrpa.main
   :members:
   :undoc-members:
   :show-inheritance:
